@@ -2,7 +2,7 @@
  *
  *  OBEX Server
  *
- *  Copyright (C) 2007-2008  Instituto Nokia de Tecnologia (INdT)
+ *  Copyright (C) 2007-2010  Nokia Corporation
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -21,16 +21,18 @@
  *
  */
 
-void emit_transfer_started(guint32 id);
+#include <dbus/dbus.h>
 
-void emit_transfer_completed(guint32 id, gboolean success);
+#define OPENOBEX_SERVICE  "org.openobex"
 
-void emit_transfer_progress(guint32 id, guint32 total, guint32 transfered);
+void manager_register_session(struct obex_session *os);
+void manager_unregister_session(struct obex_session *os);
+void manager_register_transfer(struct obex_session *os);
+void manager_unregister_transfer(struct obex_session *os);
+void manager_emit_transfer_started(struct obex_session *os);
+void manager_emit_transfer_progress(struct obex_session *os);
+void manager_emit_transfer_completed(struct obex_session *os);
+int manager_request_authorization(struct obex_session *os, int32_t time,
+		char **new_folder, char **new_name);
 
-int request_authorization(gint32 cid, int fd, const gchar *filename,
-			const gchar *type, gint32 length, gint32 time,
-			gchar **new_folder, gchar **new_name);
-
-void register_transfer(guint32 id);
-
-void unregister_transfer(guint32 id);
+DBusConnection *obex_dbus_get_connection(void);
